#include <stdio.h>
#include <libmc.h>

int main(int argc, char *argv[]) 
{
    MCAgency_t agency;
    int port=5052;
    agency = MC_Initialize(port, NULL);

    printf("MobileC Started\n");
    MC_MainLoop(agency);
    return 0;
}
